SeleniumCommandTimedOutException (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class SeleniumCommandTimedOutException

    java.lang.Object
      java.lang.Throwable
          java.lang.Exception
              java.lang.RuntimeException
                  org.openqa.selenium.server.SeleniumCommandTimedOutException

All Implemented Interfaces:
  java.io.Serializable

    public class SeleniumCommandTimedOutException

extends java.lang.RuntimeException

Thrown to indicate that the remote process failed to respond within a specified timeout.

This typically happens when the browser fails to call us back, but if the driver is using a proxy or a CommandBridge, the remote driver may have failed to give us a new command in time.

When a SeleniumCommandTimedOutException is thrown, we have to assume that the command queue is out-of-sync with the remote process (e.g. browser). When this happens, the browser should be stopped (killed) and the queue should be flushed.

Author:
  paul
See Also:
  `com.thoughtworks.selenium.outbedded.CommandBridge`, Serialized Form

Constructor Summary
`SeleniumCommandTimedOutException()`

Method Summary

Methods inherited from class java.lang.Throwable
`fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

Constructor Detail

### SeleniumCommandTimedOutException

    public SeleniumCommandTimedOutException()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.